@@ -1,11 +1,14 @@
 #' Coerce to logical if value is logical according to INCA
 #' 
-#' Boolean vectors in INCA are stored internally as 0/1 and are changed to "True"/blank when exported. These functions identify such a variable as Boolean and can coerce it to such.
+#' Boolean vectors in INCA are stored internally as 0/1 and are changed to 
+#' "True"/blank when exported. These functions identify such a variable as 
+#' Boolean and can coerce it to such.
 #' 
 #' It is common that check boxes are blanks by default but that this should 
 #' be interpreted as \code{TRUE}. There are however some uncommon cases
 #' were the boxes are marked with "False" for \code{FALSE}. 
-#' We can therefore not be certain of the meaning of a blank value. These will therefore be treated as \code{NA}.
+#' We can therefore not be certain of the meaning of a blank value. 
+#' These will therefore be treated as \code{NA}.
 #' 
 #' @param x vector (potentially logical)
 #'
@@ -23,7 +26,7 @@
 is.incalogical <- function(x) {
   if (is.logical(x) && !all(is.na(x))) {
     TRUE
-  } else if (rccmisc::is.inca()) {
+  } else if (is.inca()) {
     is.numeric(x) & 
       (0 %in% x | 1 %in% x) & 
       all(x %in% c(0:1, NA))
